summaryrefslogtreecommitdiffstats
path: root/src/H5D.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2007-07-26 13:56:09 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2007-07-26 13:56:09 (GMT)
commitbf842f1d52ea679301c8516a16e06622b9f988fb (patch)
treec0b91c681c696a5978e1a407440a808b60c9e314 /src/H5D.c
parent265833164dda0f2a6948922b95e32b5c7d9a9604 (diff)
downloadhdf5-bf842f1d52ea679301c8516a16e06622b9f988fb.zip
hdf5-bf842f1d52ea679301c8516a16e06622b9f988fb.tar.gz
hdf5-bf842f1d52ea679301c8516a16e06622b9f988fb.tar.bz2
[svn-r14017] Description:
Fix problem with fill value messages where the version of the format for a fill value message could depend on the "use the latest format" flag from the file after it was initially created. Tested on: Mac OS X/32 10.4.10 (amazon) FreeBSD/32 6.2 (duty) FreeBSD/64 6.2 (liberty)
Diffstat (limited to 'src/H5D.c')
-rw-r--r--src/H5D.c16
1 files changed, 10 insertions, 6 deletions
diff --git a/src/H5D.c b/src/H5D.c
index 13dad99..a6b9a52 100644
--- a/src/H5D.c
+++ b/src/H5D.c
@@ -1499,13 +1499,17 @@ H5D_create(H5F_t *file, hid_t type_id, const H5S_t *space, hid_t dcpl_id,
/* Get the dataset's external file list information */
if(H5P_get(dc_plist, H5D_CRT_EXT_FILE_LIST_NAME, &new_dset->shared->dcpl_cache.efl) < 0)
HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, NULL, "can't retrieve external file list")
+ } /* end if */
- /* Set the latest version of the pline & fill messages, if requested */
- if(H5F_USE_LATEST_FORMAT(file)) {
- /* Set the latest version for the I/O pipeline message */
- if(H5Z_set_latest_version(pline) < 0)
- HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, NULL, "can't set latest version of I/O filter pipeline")
- } /* end if */
+ /* Set the latest version of the pline & fill messages, if requested */
+ if(H5F_USE_LATEST_FORMAT(file)) {
+ /* Set the latest version for the I/O pipeline message */
+ if(H5Z_set_latest_version(&new_dset->shared->dcpl_cache.pline) < 0)
+ HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, NULL, "can't set latest version of I/O filter pipeline")
+
+ /* Set the latest version for the fill value message */
+ if(H5O_fill_set_latest_version(&new_dset->shared->dcpl_cache.fill) < 0)
+ HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, NULL, "can't set latest version of fill value")
} /* end if */
/* Check if this dataset is going into a parallel file and set space allocation time */